==> qtlocation-opensource-src_5.2.1.orig.tar.xz: qtlocation-opensource-src-5.2.1/src/plugins/geoservices/nokia/qgeointrinsicnetworkaccessmanager.h <==
/****************************************************************************
**
** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
** Contact: http://www.qt-project.org/legal
**
** This file is part of the QtLocation module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://qt.digia.com/licensing.  For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3.0 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU General Public License version 3.0 requirements will be
** met: http://www.gnu.org/copyleft/gpl.html.
**
**
** $QT_END_LICENSE$
**
****************************************************************************/

#ifndef QGEOINTRINSICNETWORKACCESSMANAGER_H
#define QGEOINTRINSICNETWORKACCESSMANAGER_H

#include "qgeonetworkaccessmanager.h"

#include <QMap>

QT_BEGIN_NAMESPACE

class QNetworkAccessManager;

class QGeoIntrinsicNetworkAccessManager : public QGeoNetworkAccessManager
{
public:
    explicit QGeoIntrinsicNetworkAccessManager(QObject *parent = 0);
    QGeoIntrinsicNetworkAccessManager(const QMap<QString, QVariant> &parameters, const QString &token = QString(), QObject *parent = 0);

    virtual QNetworkReply *get(const QNetworkRequest &request);
    virtual QNetworkReply *post(const QNetworkRequest &request, const QByteArray &data);

private:
    void configure(const QMap<QString, QVariant> &parameters);

    const QString m_customProxyToken;
    QNetworkAccessManager *m_networkManager;
};

QT_END_NAMESPACE

#endif // QGEOINTRINSICNETWORKACCESSMANAGER_H

==> qtlocation-opensource-src-5.3.1.tar.xz: qtlocation-opensource-src-5.3.1/src/plugins/geoservices/nokia/qgeointrinsicnetworkaccessmanager.h <==
/****************************************************************************
**
** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
** Contact: http://www.qt-project.org/legal
**
** This file is part of the QtLocation module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://qt.digia.com/licensing.  For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3.0 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU General Public License version 3.0 requirements will be
** met: http://www.gnu.org/copyleft/gpl.html.
**
**
** $QT_END_LICENSE$
**
****************************************************************************/

#ifndef QGEOINTRINSICNETWORKACCESSMANAGER_H
#define QGEOINTRINSICNETWORKACCESSMANAGER_H

#include "qgeonetworkaccessmanager.h"

#include <QMap>

QT_BEGIN_NAMESPACE

class QNetworkAccessManager;

class QGeoIntrinsicNetworkAccessManager : public QGeoNetworkAccessManager
{
public:
    explicit QGeoIntrinsicNetworkAccessManager(QObject *parent = 0);
    QGeoIntrinsicNetworkAccessManager(const QVariantMap &parameters, const QString &token = QString(), QObject *parent = 0);

    virtual QNetworkReply *get(const QNetworkRequest &request);
    virtual QNetworkReply *post(const QNetworkRequest &request, const QByteArray &data);

private:
    void configure(const QVariantMap &parameters);

    const QString m_customProxyToken;
    QNetworkAccessManager *m_networkManager;
};

QT_END_NAMESPACE

#endif // QGEOINTRINSICNETWORKACCESSMANAGER_H
